@@ -277,7 +277,11 @@ tweak_df <- function(df, quiet) {
 jma_url <- function(item = NULL,
                     block_no, year, month, day, ...) {
   .blockid <- rlang::enquo(block_no)
-  selected_item <- item
+  selected_item <-
+    rlang::arg_match(item,
+                     c("annually", "monthly", "3monthly",
+                       "10daily", "mb5daily", "daily",
+                       "hourly", "10min", "rank"))
   if (identical(selected_item, character(0))) {
     rlang::abort(intToUtf8(c(12371, 12398, 20013, 12363, 12425, 36984, 25246)))
   }
@@ -340,7 +344,58 @@ detect_station_info <- function(.blockid) {
          "a",
          station_type)
   station_type <-
-    ifelse(df_target_station$station_name %in% c(intToUtf8(c(22825, 22478)),
+    ifelse(df_target_station$station_name %in% c(intToUtf8(c(22899, 28288, 21029)),
+                                                 intToUtf8(c(26681, 23460, 20013, 27161, 27941)),
+                                                 intToUtf8(c(24111, 24195, 27849)),
+                                                 intToUtf8(c(31859, 23713)),
+                                                 intToUtf8(c(38738, 26862, 22823, 35895)),
+                                                 intToUtf8(c(33031, 31070)),
+                                                 intToUtf8(c(26481, 26681)),
+                                                 intToUtf8(c(29577, 24029)),
+                                                 intToUtf8(c(22823, 23798, 21271, 12494, 23665)),
+                                                 intToUtf8(c(26032L, 23798L)),
+                                                 intToUtf8(c(31070L, 27941L, 23798L)),
+                                                 intToUtf8(c(19977L, 23429L, 22378L, 30000L)),
+                                                 intToUtf8(c(20843L, 37325L, 35211L, 12534L, 21407L)),
+                                                 intToUtf8(c(26494L, 26412L, 20170L, 20117L)),
+                                                 intToUtf8(c(12475L, 12531L, 12488L, 12524L, 12450L)),
+                                                 intToUtf8(c(25104L, 30000L)),
+                                                 intToUtf8(c(26494L, 27996L)),
+                                                 intToUtf8(c(31179L, 12534L, 23798L)),
+                                                 intToUtf8(c(19977L, 20117L)),
+                                                 intToUtf8(c(26149L, 27743L)),
+                                                 intToUtf8(c(35914L, 20013L)),
+                                                 intToUtf8(c(20843L, 23614L)),
+                                                 intToUtf8(c(38306L, 31354L, 23798L)),
+                                                 intToUtf8(c(31070L, 25144L, 31354L, 28207L)),
+                                                 intToUtf8(c(21335L, 32000L, 30333L, 27996L)),
+                                                 intToUtf8(c(26085L, 24540L, 23546L)),
+                                                 intToUtf8(c(26412L, 37111L)),
+                                                 intToUtf8(c(35199L, 37111L, 23724L)),
+                                                 intToUtf8(c(26000L, 24029L)),
+                                                 intToUtf8(c(39640L, 27941L)),
+                                                 intToUtf8(c(28246L, 23665L)),
+                                                 intToUtf8(c(39321L, 21335L)),
+                                                 intToUtf8(c(21335L, 22269L, 26085L, 31456L)),
+                                                 intToUtf8(c(23431L, 37096L)),
+                                                 intToUtf8(c(31354L, 28207L, 21271L, 30010L)),
+                                                 intToUtf8(c(27494L, 34101L)),
+                                                 intToUtf8(c(22823L, 26449L)),
+                                                 intToUtf8(c(24029L, 21103L)),
+                                                 intToUtf8(c(30410L, 22478L)),
+                                                 intToUtf8(c(20013L, 31278L, 23376L)),
+                                                 intToUtf8(c(31520L, 21033L)),
+                                                 intToUtf8(c(21916L, 30028L, 23798L)),
+                                                 intToUtf8(c(21271L, 21407L)),
+                                                 intToUtf8(c(21271L, 22823L, 26481L)),
+                                                 intToUtf8(c(26087L, 26481L)),
+                                                 intToUtf8(c(19979L, 22320L, 23798L)),
+                                                 intToUtf8(c(20210L, 31563L)),
+                                                 intToUtf8(c(25152L, 37326L)),
+                                                 intToUtf8(c(38596, 21644)),
+                                                 intToUtf8(c(21517, 21462)),
+                                                 intToUtf8(c(27996, 20013)),
+                                                 intToUtf8(c(22825, 22478)),
                                                intToUtf8(c(19982, 35542, 23798)),
                                                intToUtf8(c(23433, 27425, 23994)),
                                                intToUtf8(c(24029, 24179)),
